
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.

< wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
*/

#include "path.h"
#include "nav.h"

#include <wx/bmpbuttn.h>

/* ---------------------------------------------------------------------------------------------- */
/* ------------------------------------ navegador ----------------------------------------------- */
/* ---------------------------------------------------------------------------------------------- */

enum idNavegador {
  ID_Chapter = 0,
  ID_SubChapter,
  ID_LastSubChapter,
  ID_NextSubChapter,
  ID_LastChapter,
  ID_NextChapter,
  ID_Example,
  ID_ChangePage,
  ID_ListSelect,
  ID_Download,
  ID_Image,
};

BEGIN_EVENT_TABLE(Navigator::PageContent, wxNotebookPage)
EVT_COMBOBOX(ID_Chapter, Navigator::PageContent::OnChangeChapter)
EVT_COMBOBOX(ID_SubChapter, Navigator::PageContent::OnChangeSubChapter)
EVT_BUTTON(ID_LastSubChapter, Navigator::PageContent::OnClickLastSubChapter)
EVT_BUTTON(ID_NextSubChapter, Navigator::PageContent::OnClickNextSubChapter)
EVT_BUTTON(ID_LastChapter, Navigator::PageContent::OnClickLastChapter)
EVT_BUTTON(ID_NextChapter, Navigator::PageContent::OnClickNextChapter)
END_EVENT_TABLE()

BEGIN_EVENT_TABLE(Navigator::PageExample, wxNotebookPage)
EVT_COMBOBOX(ID_Chapter, Navigator::PageExample::OnChangeChapter)
EVT_LISTBOX(ID_ListSelect, Navigator::PageExample::OnChangeFile)
EVT_BUTTON(ID_Download, Navigator::PageExample::OnDownload)
EVT_BUTTON(ID_Image, Navigator::PageExample::OnShowPicture)
END_EVENT_TABLE()

Navigator::Navigator(wxWindow* parent, const wxPoint& p, const wxSize& s, 
		     long style, const wxString& name):
  wxNotebook(parent, wxID_ANY, p, s, style, name)
{
  mainpage = new PageContent(this, wxT("Contenidos"));
  secpage = new PageExample(this, wxT("Ejemplos"));

  AddPage(mainpage, wxT("Contenidos"), true);
  AddPage(secpage, wxT("Ejemplos"), false);
}

void Navigator::ViewerHtml(Viewer* v)
{
  view = v;
}

void Navigator::Restore()
{
  mainpage->Restore();
  secpage->Restore();
  SetSelection(0);
}

/* ----------------------------------------------------------------- */
/* --------------------- Pestaña Contenido ------------------------- */
/* ----------------------------------------------------------------- */

Navigator::PageContent::PageContent(Navigator *parent, const wxString& s):
  wxNotebookPage((wxNotebook*)parent,-1,wxDefaultPosition, wxDefaultSize, 0, s)
{

  this->parent = parent; 

  /* Primera parte: Navegación por ComboBox. */

  labelchapter = new wxStaticText(this, wxID_ANY, wxString::FromUTF8("Capítulos: "),
				  wxPoint(50, 20), wxSize(100,15), wxALIGN_CENTRE);
  
  wxString aux[7] = {wxString::FromUTF8("1. Introducción."),
		     wxString::FromUTF8("2. Conceptos Básicos."),
		     wxString::FromUTF8("3. Componentes Básicos."),
		     wxString::FromUTF8("4. Componentes de Imagen."),
		     wxString::FromUTF8("5. Componentes de Elección."),
		     wxString::FromUTF8("6. Componentes Contenedores."),
		     wxString::FromUTF8("7. Componentes de Diálogo.")};


  chapter = new wxComboBox(this, ID_Chapter, wxString::FromUTF8("Selecciona un capítulo..."), 
			   wxPoint(35,40), wxSize(330, 30),7, aux, wxCB_DROPDOWN | wxCB_READONLY );

  labelsubchapter = new wxStaticText(this, wxID_ANY, wxString::FromUTF8("Subcapítulos: "), 
				     wxPoint(50, 100), wxSize(100,15), wxALIGN_CENTER);

  subchapter = new wxComboBox(this, ID_SubChapter, wxString::FromUTF8("Selecciona un subcapítulo..."), 
			      wxPoint(35,120), wxSize(330,30), NULL, wxCB_DROPDOWN | wxCB_READONLY);


  /* Segunda parte: Navegación por botones. */

  buttonsbox = new wxStaticBox(this, wxID_ANY, wxString::FromUTF8("Navegación: "),
			       wxPoint(10,180),  wxSize(370, 100));  

  wxInitAllImageHandlers();
  wxImage image = wxImage(48,48);

  image.LoadFile(Path::GetPathPicture(0), wxBITMAP_TYPE_PNG);
  lastchapter = new wxBitmapButton(this, ID_LastChapter, wxBitmap(image), wxPoint(33,205));
  
  image.LoadFile(Path::GetPathPicture(1), wxBITMAP_TYPE_PNG);
  lastsubchapter = new wxBitmapButton(this, ID_LastSubChapter, wxBitmap(image), wxPoint(118,205));

  image.LoadFile(Path::GetPathPicture(2), wxBITMAP_TYPE_PNG);
  nextsubchapter = new wxBitmapButton(this, ID_NextSubChapter, wxBitmap(image), wxPoint(203,205));

  image.LoadFile(Path::GetPathPicture(3), wxBITMAP_TYPE_PNG);
  nextchapter = new wxBitmapButton(this, ID_NextChapter, wxBitmap(image), wxPoint(288,205));
  
}

void Navigator::PageContent::Restore(void)
{
  chapter->SetSelection(-1);
  chapter->SetValue(wxString::FromUTF8("Selecciona un capítulo..."));
  subchapter->Clear();
  subchapter->SetValue(wxString::FromUTF8("Selecciona un subcapítulo..."));
}

void Navigator::PageContent::ChangeChapter(void)
{
  subchapter->Clear();
  subchapter->SetValue(wxString::FromUTF8("Selecciona un subcapítulo..."));

  switch(chapter->GetCurrentSelection()){
  case 0: subchapter->Insert(wxString::FromUTF8("¿Qué son las bibliotecas gráficas?."),0);
          subchapter->Insert(wxString::FromUTF8("¿Cómo programar en wxWidgets?."),1);
	  subchapter->Insert(wxString::FromUTF8("El entorno wxDevC++."),2);
	  subchapter->Insert(wxString::FromUTF8("Otras bibliotecas gráficas."),3);
    break;
  case 1: subchapter->Insert(wxString::FromUTF8("Componentes."),0);
          subchapter->Insert(wxString::FromUTF8("Tipos de datos."),1);
	  subchapter->Insert(wxString::FromUTF8("Eventos."),2);
	  subchapter->Insert(wxString::FromUTF8("Primer Ejemplo."),3);
    break;
  case 2: subchapter->Insert(wxString::FromUTF8("wxApp, wxFrame, wxButton."),0);
          subchapter->Insert(wxString::FromUTF8("wxStaticText, wxTextCtrl."),1);
	  subchapter->Insert(wxString::FromUTF8("wxMenu."),2);
    break;
  case 3: subchapter->Insert(wxString::FromUTF8("Imagen"),0);
    break;
  case 4: subchapter->Insert(wxString::FromUTF8("wxChoice, wxComboBox, wxListBox."),0);
          subchapter->Insert(wxString::FromUTF8("wxCheckBox, wxRadioBox."),1);
    break;
  case 5: subchapter->Insert(wxString::FromUTF8("wxPanel."),0);
          subchapter->Insert(wxString::FromUTF8("wxNotebook."),1);
	  subchapter->Insert(wxString::FromUTF8("wxHtmlWindow."),2);
    break;
  case 6: subchapter->Insert(wxString::FromUTF8("wxDialog."),0);
          subchapter->Insert(wxString::FromUTF8("Diálogos de entrada de datos."),1); 
          subchapter->Insert(wxString::FromUTF8("Diálogos de salida de datos."),2);
	  subchapter->Insert(wxString::FromUTF8("Diálogos de ficheros."),3);
    break;
  }

}

void Navigator::PageContent::ChangeSubChapter(void)
{
  switch(chapter->GetCurrentSelection()) {
  case 0: {
    switch(subchapter->GetCurrentSelection()) {
    case 0: parent->view->LoadPage(Path::GetPathHtml(1)); break;
    case 1: parent->view->LoadPage(Path::GetPathHtml(2)); break;
    case 2: parent->view->LoadPage(Path::GetPathHtml(3)); break;
    case 3: parent->view->LoadPage(Path::GetPathHtml(4)); break;
    }  
  }
    break;

  case 1: {
    switch(subchapter->GetCurrentSelection()){
    case 0: parent->view->LoadPage(Path::GetPathHtml(5)); break;
    case 1: parent->view->LoadPage(Path::GetPathHtml(6)); break;
    case 2: parent->view->LoadPage(Path::GetPathHtml(7)); break;
    case 3: parent->view->LoadPage(Path::GetPathHtml(8)); break;
    }
  }
    break;

  case 2: {  
    switch(subchapter->GetCurrentSelection()){
    case 0: parent->view->LoadPage(Path::GetPathHtml(9)); break;
    case 1: parent->view->LoadPage(Path::GetPathHtml(10)); break;
    case 2: parent->view->LoadPage(Path::GetPathHtml(11)); break;
    }
  }
    break;

  case 3: parent->view->LoadPage(Path::GetPathHtml(12));
    break;

  case 4: {
    switch(subchapter->GetCurrentSelection()){
    case 0: parent->view->LoadPage(Path::GetPathHtml(13)); break;
    case 1: parent->view->LoadPage(Path::GetPathHtml(14)); break;
    }
  }
    break;

  case 5: {
    switch(subchapter->GetCurrentSelection()){
    case 0: parent->view->LoadPage(Path::GetPathHtml(15)); break;
    case 1: parent->view->LoadPage(Path::GetPathHtml(16)); break;
    case 2: parent->view->LoadPage(Path::GetPathHtml(17)); break;
    }
  }
    break;

  case 6:{
    switch(subchapter->GetCurrentSelection()){
    case 0: parent->view->LoadPage(Path::GetPathHtml(18)); break;
    case 1: parent->view->LoadPage(Path::GetPathHtml(19)); break;
    case 2: parent->view->LoadPage(Path::GetPathHtml(20)); break;
    case 3: parent->view->LoadPage(Path::GetPathHtml(21)); break;
    }
  }
    break;
  }
    
}

void Navigator::PageContent::OnChangeChapter(wxCommandEvent& event)
{
  ChangeChapter();
}

void Navigator::PageContent::OnChangeSubChapter(wxCommandEvent& event)
{
  ChangeSubChapter();
}

void Navigator::PageContent::OnClickLastSubChapter(wxCommandEvent& event)
{
  if(subchapter->GetCurrentSelection() > 0){
    subchapter->SetSelection(subchapter->GetCurrentSelection()-1);
    ChangeSubChapter();
    }
}

void Navigator::PageContent::OnClickNextSubChapter(wxCommandEvent& event)
{
  switch(chapter->GetCurrentSelection()){
  case 0: 
  case 1: if(subchapter->GetCurrentSelection() != 3) {
      subchapter->SetSelection(subchapter->GetCurrentSelection()+1);
      ChangeSubChapter();
    }
    break;
  case 2: if(subchapter->GetCurrentSelection() != 2) {
      subchapter->SetSelection(subchapter->GetCurrentSelection()+1);
      ChangeSubChapter();
    }
    break;
  case 3: if(subchapter->GetCurrentSelection() != 0) {
      subchapter->SetSelection(subchapter->GetCurrentSelection()+1);
      ChangeSubChapter();
    }
    break;
  case 4: 
  case 5: if(subchapter->GetCurrentSelection() != 2) {
      subchapter->SetSelection(subchapter->GetCurrentSelection()+1);
      ChangeSubChapter();
    }
    break;
  case 6: if(subchapter->GetCurrentSelection() != 3) {
      subchapter->SetSelection(subchapter->GetCurrentSelection()+1);
      ChangeSubChapter();
    }
    break;
  }
  
}

void Navigator::PageContent::OnClickLastChapter(wxCommandEvent& event)
{
  if(chapter->GetCurrentSelection() > 0){
    chapter->SetSelection(chapter->GetCurrentSelection()-1);
    ChangeChapter();
    subchapter->SetValue(wxString::FromUTF8("Selecciona un subcapítulo..."));
  }
}

void Navigator::PageContent::OnClickNextChapter(wxCommandEvent& event)
{
  if(chapter->GetCurrentSelection() != 6){
    chapter->SetSelection(chapter->GetCurrentSelection()+1);
    ChangeChapter();
    subchapter->SetValue(wxString::FromUTF8("Selecciona un subcapítulo..."));
  }
}


/* ----------------------------------------------------------------- */
/* --------------------- Pestaña Ejemplo --------------------------- */
/* ----------------------------------------------------------------- */

Navigator::PageExample::PageExample(Navigator* parent, const wxString& title):
  wxNotebookPage((wxNotebook*)parent,-1,wxDefaultPosition, wxDefaultSize, 0, title)
{

  this->parent= parent;
    
  labelexample = new wxStaticText(this, wxID_ANY, wxT("Ejemplos: "), 
				  wxPoint(50, 20), wxSize(100,15), wxALIGN_CENTRE);

  labelfile = new wxStaticText(this, wxID_ANY, wxT("Ficheros: "), 
			       wxPoint(50, 105), wxSize(100,15), wxALIGN_CENTRE);

  wxString aux[4] = {wxString::FromUTF8("Primer ejemplo (Hola Mundo)"),
		     wxString::FromUTF8("Segundo ejemplo (Baja dificultad)"),
		     wxString::FromUTF8("Tercer ejemplo (Media dificultad)"),
		     wxString::FromUTF8("Cuarto ejemplo (wxTutorial)")};

  example = new wxComboBox(this, ID_Chapter, wxT("Selecciona un ejemplo..."), 
			   wxPoint(35,40), wxSize(330, 30), 4, aux, wxCB_DROPDOWN | wxCB_READONLY );

  file = new wxListBox(this, ID_ListSelect, wxPoint(35,125), wxSize(330,100));

  wxImage img = wxImage(48,48);
 
  img.LoadFile(Path::GetPathPicture(6), wxBITMAP_TYPE_PNG);
  view = new wxBitmapButton(this, ID_Download, wxBitmap(img), wxPoint(100,250));
  
  img.LoadFile(Path::GetPathPicture(7), wxBITMAP_TYPE_PNG);
  download = new wxBitmapButton(this, ID_Image, wxBitmap(img), wxPoint(252,250));
  
  if(example->GetCurrentSelection() == -1){
    view->Enable(false);
    download->Enable(false);
  }

}
  
void Navigator::PageExample::Restore()
{
  example->SetValue(wxString::FromUTF8("Selecciona un ejemplo..."));
  file->Clear();
  view->Enable(false);
  download->Enable(false);
}

void Navigator::PageExample::OnChangeChapter(wxCommandEvent& event)
{

  if(example->GetCurrentSelection() == -1){
    view->Enable(false);
    download->Enable(false);
  }
  else {
    view->Enable(true);
    download->Enable(true);
  }
  
  file->Clear();
  switch(example->GetCurrentSelection()){
  case 0: {
    file->Insert(wxString::FromUTF8("holamundo.h"),0);
    file->Insert(wxString::FromUTF8("holamundo.cpp"),1);
  }
    break;
  case 1: {
    file->Insert(wxString::FromUTF8("ejemploCap03.h"),0);
    file->Insert(wxString::FromUTF8("ejemploCap03.cpp"),1);
  }
    break;
  case 2: {
    file->Insert(wxString::FromUTF8("ejemploCap05.h"),0);
    file->Insert(wxString::FromUTF8("ejemploCap05.cpp"),1);
    //...
  }
    break;
  case 3: {
    file->Insert(wxString::FromUTF8("app.h"),0);
    file->Insert(wxString::FromUTF8("app.cpp"),1);
    file->Insert(wxString::FromUTF8("path.h"),2);
    file->Insert(wxString::FromUTF8("path.cpp"),3);
    file->Insert(wxString::FromUTF8("form.h"),4);
    file->Insert(wxString::FromUTF8("form.cpp"),5);
    file->Insert(wxString::FromUTF8("viewer.h"),6);
    file->Insert(wxString::FromUTF8("viewer.cpp"),7);
    file->Insert(wxString::FromUTF8("nav.h"),8);
    file->Insert(wxString::FromUTF8("nav.cpp"),9);
    file->Insert(wxString::FromUTF8("dexp.h"),10);
    file->Insert(wxString::FromUTF8("dexp.cpp"),11);
    file->Insert(wxString::FromUTF8("dshow.h"),12);
    file->Insert(wxString::FromUTF8("dshow.cpp"),13);
    file->Insert(wxString::FromUTF8("ddl.h"),14);
    file->Insert(wxString::FromUTF8("ddl.cpp"),15);
    file->Insert(wxString::FromUTF8("dimag.h"),16);
    file->Insert(wxString::FromUTF8("dimag.cpp"),17);
  }
    break;
  }

}
    
void Navigator::PageExample::OnChangeFile(wxCommandEvent& event)
{
  switch(example->GetCurrentSelection()){
  case 0: {
    if(file->IsSelected(0))
      parent->view->LoadPage(Path::GetPathCode(0));
    if(file->IsSelected(1))
      parent->view->LoadPage(Path::GetPathCode(1));
  }
    break;
  case 1: {
    if(file->IsSelected(0))
      parent->view->LoadPage(Path::GetPathCode(2));
    if(file->IsSelected(1))
      parent->view->LoadPage(Path::GetPathCode(3));
  }
    break;
  case 2: {
    if(file->IsSelected(0))
      parent->view->LoadPage(Path::GetPathCode(4));
    if(file->IsSelected(1))
      parent->view->LoadPage(Path::GetPathCode(5));
  }
    break;
  case 3: {
    if(file->IsSelected(0))
      parent->view->LoadPage(Path::GetPathCode(6));
    if(file->IsSelected(1))
      parent->view->LoadPage(Path::GetPathCode(7));
    if(file->IsSelected(2))
      parent->view->LoadPage(Path::GetPathCode(8));
    if(file->IsSelected(3))
      parent->view->LoadPage(Path::GetPathCode(9));
    if(file->IsSelected(4))
      parent->view->LoadPage(Path::GetPathCode(10));
    if(file->IsSelected(5))
      parent->view->LoadPage(Path::GetPathCode(11));
    if(file->IsSelected(6))
      parent->view->LoadPage(Path::GetPathCode(12));
    if(file->IsSelected(7))
      parent->view->LoadPage(Path::GetPathCode(13));
    if(file->IsSelected(8))
      parent->view->LoadPage(Path::GetPathCode(14));
    if(file->IsSelected(9))
      parent->view->LoadPage(Path::GetPathCode(15));
    if(file->IsSelected(10))
      parent->view->LoadPage(Path::GetPathCode(16));
    if(file->IsSelected(11))
      parent->view->LoadPage(Path::GetPathCode(17));
    if(file->IsSelected(12))
      parent->view->LoadPage(Path::GetPathCode(18));
    if(file->IsSelected(13))
      parent->view->LoadPage(Path::GetPathCode(19));
    if(file->IsSelected(14))
      parent->view->LoadPage(Path::GetPathCode(20));
    if(file->IsSelected(15))
      parent->view->LoadPage(Path::GetPathCode(21));
    if(file->IsSelected(16))
      parent->view->LoadPage(Path::GetPathCode(22));
    if(file->IsSelected(17))
      parent->view->LoadPage(Path::GetPathCode(23));
  }
    break;
  }

}

void Navigator::PageExample::OnDownload(wxCommandEvent& event)
{
  wxFileDialog* savefile = new wxFileDialog(this, wxString::FromUTF8("Descargar ejecutable:"),
					    wxString::FromUTF8(""), wxString::FromUTF8(""),
					    wxString::FromUTF8("*.zip"), wxFD_SAVE);
  savefile->ShowModal();
  if(savefile->GetReturnCode() == wxID_OK){
    wxString getpath = savefile->GetPath();
    
#ifdef __WXGTK__
    getpath = getpath + wxString::FromUTF8(".zip");
#endif
    
    wxCopyFile(Path::GetPathExe(example->GetCurrentSelection()), getpath, true);
  }
}
  
void Navigator::PageExample::OnShowPicture(wxCommandEvent& event)
{
  dialogimage = new DialogImage(this, wxID_ANY, wxString::FromUTF8("Imágenes"), 
				example->GetCurrentSelection());
  dialogimage->ShowModal();
}
