
/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.

 * < wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
 * Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
 */

#ifndef _VIEWER_
#define _VIEWER_

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#include <wx/wx.h>
#include <wx/html/htmlwin.h>

class Navigator;

/**
 * @brief Definición del visualizador de contenido.
 *
 * @author Rosa María Durante Lerate.
 * @note Parte del proyecto wxTutorial!.
 */
class Viewer
{
 public:
  /**
   * @brief Constructor de la clase.
   * @param parent Puntero de tipo wxWindow siendo éste
   * el componente donde se ha llamado al diálogo.
   * @param p Posición del visor en la aplicación.
   * @param s Tamaño del visor en la aplicación.
   * @param style Estilos del visor.
   * @param name Nombre del componente.
   */
  Viewer(wxWindow* parent, wxWindowID id, const wxPoint& p, const wxSize& s, 
	 long style = 0, const wxString& name = wxString::FromUTF8("VisorHtml"));
  /**
   * @brief Carga un artículo/código en el visor.
   * @param s Ruta del fichero a visualizar.
   */
  void LoadPage(const wxString& s);
  /**
   * @brief Función que asocia dos clases (Viewer - Navegator).
   * @param n Puntero de tipo Navegator para crear la asociación.
   */
  void Nav(Navigator* n);
  
 private:
  wxFileName *file;
  Navigator *nav;
  wxStaticBox *box;
  wxHtmlWindow *html;
};

#endif
